@@ -38,6 +38,7 @@ public:
     }
 
     bool setItemsFlags(const PimItem::List &items,
+                               const QVector<Flag> *currentFlags,
                                const QVector<Flag> &flags,
                                bool *flagsChanged = nullptr,
                                const Collection &col = Collection(),
@@ -123,7 +124,6 @@ protected:
     QMap<QString, QVariantList> mChanges;
 
 private:
-    bool populateDatabase();
     bool mPopulateDb;
 
 };
