@@ -11,7 +11,7 @@
 
 using namespace Akonadi;
 
-Config Config::sConfig{};
+Q_GLOBAL_STATIC(Config, sConfig) // NOLINT(readability-redundant-member-init)
 
 namespace {
 
@@ -44,7 +44,7 @@ Config::Config()
     }
 }
 
-void Config::setConfig(const Config &config)
+const Config &Config::get()
 {
-    sConfig = config;
+    return *sConfig;
 }
