@@ -14,12 +14,10 @@ namespace Akonadi
 class Config
 {
 public:
+    explicit Config();
     ~Config() = default;
 
-    static const Config &get()
-    {
-        return sConfig;
-    }
+    static const Config &get();
 
     struct PayloadCompression {
         /**
@@ -36,15 +34,6 @@ public:
      * Configures behavior of the payload compression feature.
      */
     PayloadCompression payloadCompression = {};
-
-
-protected:
-    explicit Config();
-
-    static void setConfig(const Config &config);
-
-private:
-    static Config sConfig;
 };
 
 } // namespace Akonadi
