@@ -10,7 +10,6 @@
 
 #include "job_p.h"
 #include "collection.h"
-#include "item.h"
 #include "item_p.h"
 #include "itemcreatejob.h"
 #include "itemdeletejob.h"
@@ -77,7 +76,7 @@ public:
     QSet<QString> mListedItems;
 
     ItemSync::TransactionMode mTransactionMode;
-    TransactionSequence *mCurrentTransaction;
+    TransactionSequence *mCurrentTransaction = nullptr;
     int mTransactionJobs;
 
     // fetch scope for initial item listing
