@@ -12,7 +12,6 @@
 
 #include <QSqlError>
 #include <QDir>
-#include <QProcess>
 #include <QThread>
 #include <QRegularExpression>
 #include <QSqlDriver>
@@ -65,7 +64,7 @@ static QString findExecutable(const QString &bin)
     return path;
 }
 
-bool DbConfigMysql::init(QSettings &settings)
+bool DbConfigMysql::init(QSettings &settings, bool storeSettings)
 {
     // determine default settings depending on the driver
     QString defaultHostName;
@@ -134,17 +133,19 @@ bool DbConfigMysql::init(QSettings &settings)
 
     qCDebug(AKONADISERVER_LOG) << "Using mysqld:" << mMysqldPath;
 
-    // store back the default values
-    settings.beginGroup(driverName());
-    settings.setValue(QStringLiteral("Name"), mDatabaseName);
-    settings.setValue(QStringLiteral("Host"), mHostName);
-    settings.setValue(QStringLiteral("Options"), mConnectionOptions);
-    if (!mMysqldPath.isEmpty()) {
-        settings.setValue(QStringLiteral("ServerPath"), mMysqldPath);
+    if (storeSettings) {
+        // store back the default values
+        settings.beginGroup(driverName());
+        settings.setValue(QStringLiteral("Name"), mDatabaseName);
+        settings.setValue(QStringLiteral("Host"), mHostName);
+        settings.setValue(QStringLiteral("Options"), mConnectionOptions);
+        if (!mMysqldPath.isEmpty()) {
+            settings.setValue(QStringLiteral("ServerPath"), mMysqldPath);
+        }
+        settings.setValue(QStringLiteral("StartServer"), mInternalServer);
+        settings.endGroup();
+        settings.sync();
     }
-    settings.setValue(QStringLiteral("StartServer"), mInternalServer);
-    settings.endGroup();
-    settings.sync();
 
     // apply temporary changes to the settings
     if (mInternalServer) {
@@ -156,6 +157,23 @@ bool DbConfigMysql::init(QSettings &settings)
     return true;
 }
 
+bool DbConfigMysql::isAvailable(QSettings &settings)
+{
+    if (!QSqlDatabase::drivers().contains(driverName())) {
+        return false;
+    }
+
+    if (!init(settings, false)) {
+        return false;
+    }
+
+    if (mInternalServer && (mMysqldPath.isEmpty() || !QFile::exists(mMysqldPath))) {
+        return false;
+    }
+
+    return true;
+}
+
 void DbConfigMysql::apply(QSqlDatabase &database)
 {
     if (!mDatabaseName.isEmpty()) {
