@@ -40,9 +40,15 @@ public:
      * and before the initial database connection is set up.
      *
      * At this point the default settings should be determined, merged
-     * with the given @p settings and written back.
+     * with the given @p settings and written back if @p storeSettings is true.
      */
-    bool init(QSettings &settings) override;
+    bool init(QSettings &settings, bool storeSettings = true) override;
+
+    /**
+     * This method checks if the requirements for this database connection are met
+     * in the system (QSQLITE/QSQLITE3 driver is available, object can be initialized, etc.).
+     */
+    bool isAvailable(QSettings &settings) override;
 
     /**
      * This method applies the configured settings to the QtSql @p database
