@@ -230,7 +230,7 @@ bool DragDropManager::processDropEvent(QDropEvent *event, bool &menuCanceled, bo
     popup.addSeparator();
     QAction *cancelAction = popup.addAction(QIcon::fromTheme(QStringLiteral("process-stop")), i18n("C&ancel") + QLatin1Char('\t') + QKeySequence(Qt::Key_Escape).toString());
 
-    QAction *activatedAction = popup.exec(m_view->mapToGlobal(event->pos()));
+    QAction *activatedAction = popup.exec(m_view->viewport()->mapToGlobal(event->pos()));
     if (!activatedAction || (activatedAction == cancelAction)) {
         menuCanceled = true;
         return false;
